@@ -25,7 +25,7 @@
 #define FST_fst_h_
 
 #define FST_MAJOR_VERSION 0
-#define FST_MINOR_VERSION 175
+#define FST_MINOR_VERSION 177
 #define FST_MICRO_VERSION 0
 
 #define FST_VERSIONNUM(X, Y, Z)                                         \
@@ -293,6 +293,9 @@ typedef enum {
 
 
   FST_EFFECT_OPCODE(SetProcessPrecision, 77), /* IN:ivalue(ProcessPrecision64,..), return !isProcessing */
+  FST_EFFECT_OPCODE(GetNumMidiInputChannels, 78), /* return 16*isMidi */
+  FST_EFFECT_OPCODE(GetNumMidiOutputChannels, 79), /* return 16*isMidi */
+
 
 
   FST_EFFECT_OPCODE_UNKNOWN(EditDraw),
@@ -300,9 +303,6 @@ typedef enum {
   FST_EFFECT_OPCODE_UNKNOWN(EditSleep),
   FST_EFFECT_OPCODE_UNKNOWN(EditTop),
 
-  FST_EFFECT_OPCODE_UNKNOWN(GetNumMidiInputChannels), /* return 16*isMidi */
-  FST_EFFECT_OPCODE_UNKNOWN(GetNumMidiOutputChannels), /* return 16*isMidi */
-
   FST_EFFECT_OPCODE_UNKNOWN(SetBypass), /* IN:ivalue, return 0; effCanDo("bypass") */
 
 FST_WARNING("document origin of eff*SetProgram")
@@ -480,7 +480,7 @@ enum {
 
       FST_CONSTANT(ProcessLevelOffline, 4),
 
-FST_WARNING("document origin of ProcesslevelUser")
+FST_WARNING("document origin of ProcessLevelUser")
       FST_CONSTANT_UNKNOWN(ProcessLevelUser), /* vstplugin~ */
 };
 
