@@ -181,10 +181,8 @@ static void test_setParameter(AEffect*effect) {
     snprintf(buf, 511, "%s", "0.2");
     buf[511] = 0;
     post("\ttesting#%d", opcode);
-    fflush(stdout);
     value = test_setParameterS(effect, opcode, 0, buf);
     post("\t#%d: '%s' -> %f", opcode, buf, value);
-    fflush(stdout);
   }
 }
 
@@ -209,6 +207,17 @@ static void test_opcode42(AEffect*effect) {
   }
 }
 
+bool skipOpcodePtr(size_t opcode) {
+  switch(opcode) {
+  default: break;
+  case effProcessEvents:
+  case effEditOpen:
+  case effSetSpeakerArrangement:
+  case effGetSpeakerArrangement:
+    return true;
+  }
+  return false;
+}
 
 bool skipOpcode(size_t opcode) {
 
@@ -275,40 +284,55 @@ void test_opcodes(AEffect*effect, size_t endopcode=78, size_t startopcode=10) {
   return 0;
 #endif
   //  endopcode = 0xDEADF00D+1;
-  for(size_t i=startopcode; i<endopcode; i++) {
-    curOpCode = i;
-    if(!(i%65536)) {
-      post("=== mark %d ===", i>>16);
-      fflush(stdout);
+  for(size_t opcode=startopcode; opcode<endopcode; opcode++) {
+    post("testing %s [%d..%d]", effCode2string(opcode), startopcode, endopcode);
+    curOpCode = opcode;
+    if(!(opcode%65536)) {
+      post("=== mark %d ===", opcode>>16);
     }
-    if (skipOpcode(i)
+#if 1
+    if(skipOpcodePtr(opcode))
+       continue;
+#endif
+    if (skipOpcode(opcode)
 #ifdef NOSKIP
-        && (NOSKIP != i)
+        && (NOSKIP != opcode)
 #endif
         ) {
-      post("skipping: %d", i);
+      post("skipping: %d", opcode);
       continue;
     }
-    //post("trying: %d", i);
+    //post("trying: %d", opcode);
     char buffer[200000] = { 0 };
-    snprintf(buffer, 511, "name%d", i);
-    t_fstPtrInt res = dispatch (effect, i, 0, 0, buffer, 0);
-    if(res || (buffer && *buffer))
-        post("tried: %d", i);
+    snprintf(buffer, 511, "name%d", opcode);
 
+    int index = 0;
+    t_fstPtrInt ivalue = 0;
+    void*ptr=buffer;
+    float fvalue = 0.f;
 
+    post("host2plugin('%s', '%s', %s, %s, %p, %f)",
+	 effectname, effCode2string(opcode),
+	 int2str(index),
+	 int2str2(ivalue),
+	 ptr, fvalue);
+    t_fstPtrInt res = dispatch (effect, opcode, index, ivalue, ptr, fvalue);
+    post("host2plugin: %s (%s)", int2str(res), effCode2string(opcode));
+
+#if 0
     if(res) {
       const char*str = (const char*)res;
-      post("\t[%d=0x%X]: %.*s", i, res, res, 32, str);
+      post("\t[%s]: %.*s", int2str(res), 32, str);
     }
+#endif
     if(*buffer)
       post("\tbuffer '%.*s'", 512, buffer);
-    switch(i) {
+    switch(opcode) {
     default: break;
     case 4:
       post_hex(buffer, 16);
     }
-    fstpause();
+    fstpause(0.2);
   }
   do {
     char buffer[200000] = { 0 };
@@ -536,7 +560,7 @@ int test_plugin(const char*filename) {
   //test_opcode29(effect); return 0;
   test_opcode3334(effect);
   //test_opcodesJUCE(effect);
-  //test_opcodes(effect, 78);
+  test_opcodes(effect, 129, 9);
 
   //test_unknown(effect);
   test_SpeakerArrangement1(effect);
