@@ -57,7 +57,7 @@ t_fstPtrInt dispatch_v (AEffect* effect, int opcode, int index, t_fstPtrInt ival
   if(effect) {
     if(doprint) {
       char opcodestr[256];
-      printf("FST::FstPlugin::plugin2host(%p, %s, %d, %lu, %p, %f) => ",  effect, hostCode2string(opcode, opcodestr, 255), index, ivalue, ptr, fvalue);
+      print("FST::FstPlugin::plugin2host(%p, %s, %d, %lu, %p, %f) => ",  effect, hostCode2string(opcode, opcodestr, 255), index, ivalue, ptr, fvalue);
     }
     t_fstPtrInt result = dispatch(effect, opcode, index, ivalue, ptr, fvalue);
     if(doprint)
@@ -517,16 +517,16 @@ static t_fstPtrInt dispatcher(AEffect*eff, t_fstInt32 opcode, int index, t_fstPt
     switch(index) {
       /* the 'stCA' code seems to be common among hosts ... */
     case FOURCC("stCA"):
-      printf("FST::FstPlugin::%s(effVendorSpecific/%.4s/%.4s) ", __FUNCTION__, fourcc2str(index), fourcc2str(ivalue, buf));
+      print("FST::FstPlugin::%s(effVendorSpecific/%.4s/%.4s) ", __FUNCTION__, fourcc2str(index), fourcc2str(ivalue, buf));
       switch(ivalue) {
       case FOURCC("Whee"):
-        printf("MouseWheel");
+        print("MouseWheel");
         break;
       default:
-        printf("(0x%08X)", ivalue);
+        print("(0x%08X)", ivalue);
         break;
       }
-      printf("\n");post();
+      print("\n");post();
       break;
       /*
         https://www.reaper.fm/sdk/vst/vst_ext.php
@@ -621,6 +621,7 @@ static void processDoubleReplacing(AEffect*eff, double**indata, double**outdata,
 extern "C"
 AEffect*VSTPluginMain(AEffectDispatcherProc dispatch4host) {
   dispatch = dispatch4host;
+  print_init();
   post("FstPlugin::main(%p)", dispatch4host);
   for(size_t i=0; i<SIZEOF(parameters); i++)
     parameters[i] = 0.5;
@@ -711,6 +712,5 @@ AEffect*VSTPluginMain(AEffectDispatcherProc dispatch4host) {
 
   post("=====================================");
   post(""); post("");
-
   return eff;
 }
