@@ -39,6 +39,14 @@ t_fstPtrInt host2plugin (AEffect* effect, int opcode, int index, t_fstPtrInt iva
       //{"hasCockosSampleAccurateAutomation", 1 /* ? */ },
       //{"hasCockosViewAsConfig", 1 /* ? */ },
       //{"cockosLoadingConfigAsParameters", 1 /* ? */ },
+
+      //{"receiveVstEvents", 1},
+      //{"receiveVstMidiEvent", 1},
+      //{"sendVstEvents", 1},
+      //{"sendVstMidiEvent", 1},
+      //{"supportsGainReductionInfo", 1},
+      //{"wantsChannelCountNotifications", 1},
+
       {0, 0} /* END */
     };
     t_cando*cando;
@@ -162,12 +170,12 @@ t_fstPtrInt plugin2host (AEffect* effect, int opcode, int index, t_fstPtrInt iva
 #endif
   switch(opcode) {
   default: break;
-  case 14:
-    post("hostCODE14");
+  case audioMasterNeedIdle:
+    post("audioMasterNeedIdle");
     //return 1;
     break;
-  case 42:
-    post("hostCODE42");
+  case audioMasterUpdateDisplay:
+    post("audioMasterUpdateDisplay");
     //return 0;
     break;
   case audioMasterGetCurrentProcessLevel:
@@ -206,6 +214,7 @@ extern "C"
 AEffect*VSTPluginMain(AEffectDispatcherProc dispatch4host) {
   char pluginname[512] = {0};
   char*pluginfile = getenv("FST_PROXYPLUGIN");
+  print_init();
   post("FstProxy: '%s'", pluginfile);
   if(!pluginfile)return 0;
   s_plug2host = dispatch4host;
