@@ -1,4 +1,4 @@
-#include "fst/fst.h"
+#include "fst.h"
 
 int main(void) {
     return 0;
