@@ -1,4 +1,4 @@
-#include "fst/fst.h"
+#include "fst.h"
 
 #if defined(_LANGUAGE_C_PLUS_PLUS) || defined(__cplusplus)
 extern "C"
